==> gottet_1.1.9.orig.tar.gz: gottet-1.1.9/translations/gottet_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>問題</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>結束目前的遊戲？</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;已暫停&lt;/b&gt;&lt;/big&gt;&lt;br&gt;點擊以繼續進行遊戲。</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;遊戲結束！&lt;/b&gt;&lt;/big&gt;&lt;br&gt;點擊以開啟一個新遊戲。</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>選擇應用程式語言：</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;系統語言&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>註記</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>請重新啟動此應用程式以使語言的更動生效。</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>Gottet 分數</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>等級</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>行數</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>分數</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>點擊以開啟一個新遊戲。</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>遊戲(&amp;G)</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新遊戲(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>暫停(&amp;P)</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>繼續(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>分數(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>離開(&amp;Q)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>設定(&amp;S)</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>應用程式語言...(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>求助(&amp;H)</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>關於 Qt(&amp;Q)</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>下一個</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>等級</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>已移除的行數</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>分數</translation>
    </message>
    <message>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>獻給我妻子的一個俄羅斯方塊克隆</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>以 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 授權條款釋出</translation>
    </message>
</context>
</TS>

==> gottet_1.2.4.orig.tar.gz: gottet-1.2.4/translations/gottet_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>問題</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>結束目前的遊戲？</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;已暫停&lt;/b&gt;&lt;/big&gt;&lt;br&gt;點擊以繼續進行遊戲。</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;遊戲結束！&lt;/b&gt;&lt;/big&gt;&lt;br&gt;點擊以開啟一個新遊戲。</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>選擇應用程式語言：</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;系統語言&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>註記</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>請重新啟動此應用程式以使語言的更動生效。</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>等級</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>行數</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>分數</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation>高分</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>排行</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>恭喜！</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>您擊敗了您的最高分！</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>很好！</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>您有新的高分！</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>點擊以開啟一個新遊戲。</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>遊戲(&amp;G)</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新遊戲(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>暫停(&amp;P)</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>分數(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>離開(&amp;Q)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>設定(&amp;S)</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>應用程式語言...(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>求助(&amp;H)</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>關於 Qt(&amp;Q)</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>下一個</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>等級</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>已移除的行數</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>分數</translation>
    </message>
    <message>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>以 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 授權條款釋出</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation>一個簡單的方塊掉落遊戲</translation>
    </message>
</context>
</TS>
